Crate cargo_utils

source ·

Structs

Dependency table to add dep to
A Cargo manifest that is available locally.
A Cargo manifest

Enums

Functions

If a manifest is specified, return that one, otherise perform a manifest search starting from the current directory. If a manifest is specified, return that one. If a path is specified, perform a manifest search starting from there. If nothing is specified, start searching from the current directory (cwd).
Find the URL of a registry
Upgrade an existing requirement to a new version
Lookup all members of the current workspace